@@ -234,7 +234,7 @@ class Archive(Mesh):
 
 
 def save_as_archive(filename, grid, mtype_start=1, etype_start=1,
-                    real_constant_start=1, mode='w', nblock=True,
+                    real_constant_start=1, mode='w',
                     enum_start=1, nnum_start=1,
                     include_etype_header=True, reset_etype=False,
                     allow_missing=True, include_surface_elements=True,
@@ -284,9 +284,6 @@ def save_as_archive(filename, grid, mtype_start=1, etype_start=1,
     mode : str, optional
         File mode.  See ``help(open)``
 
-    nblock : bool, optional
-        Write node block when writing archive file.
-
     enum_start : int, optional
         Starting element number to assign to unset cells.  Can be
         manually set by adding the cell array "ansys_elem_num" to the
@@ -329,7 +326,6 @@ def save_as_archive(filename, grid, mtype_start=1, etype_start=1,
     >>> pymapdl_reader.save_as_archive('archive.cdb', grid)
 
     """
-
     if isinstance(grid, pv.PolyData):
         grid = grid.cast_to_unstructured_grid()
 
